@@ -30,8 +30,8 @@ class GroupWiseAdvancedSettingsWidget : public AbstractAccountParametersWidget
     Q_OBJECT
 
 public:
-    explicit GroupWiseAdvancedSettingsWidget(ParameterEditModel *model, QWidget *parent = 0);
-    virtual ~GroupWiseAdvancedSettingsWidget();
+    explicit GroupWiseAdvancedSettingsWidget(ParameterEditModel *model, QWidget *parent = nullptr);
+    ~GroupWiseAdvancedSettingsWidget() override;
 
 private:
     Q_DISABLE_COPY(GroupWiseAdvancedSettingsWidget)
